/*
 * AndroidBitmap.h
 *
 *  Created on: Feb 3, 2013
 *      Author: omergilad
 */

#ifndef ANDROIDBITMAP_H_
#define ANDROIDBITMAP_H_

#include "common/scummsys.h"
#include "common/str.h"

using Common::String;

class AndroidBitmap {

public:

	AndroidBitmap() :
			pixels(NULL), glTextureX(0), glTextureY(0), displayWidth(0), displayHeight(
					0), bpp(0), ratio(0.0), width(0), height(0) {
	}

	/**
	 * Copy constructor for creating a snapshot
	 */
	AndroidBitmap(AndroidBitmap& other) {
		glTexture = other.glTexture;
		glTextureX = other.glTextureX;
		glTextureY = other.glTextureY;
		displayWidth = other.displayWidth;
		displayHeight = other.displayHeight;
		bitmapName = other.bitmapName;
		sourceContainsAlpha = other.sourceContainsAlpha;
		drawWithScaling = other.drawWithScaling;
		ratio = other.getRatio();
		width = other.getWidth();
		height = other.getHeight();
		bpp = other.bpp;

		// Copy the pixels
		uint32 size = width * height * bpp;
		LOGD("AndroidBitmap: copying w %d h %d bpp %d", width, height, bpp);
		pixels = new byte[size];
		memcpy(pixels, other.getPixels(), size);
	}

	virtual ~AndroidBitmap() {

		if (pixels != NULL) {
			delete[] pixels;
		}
	}

	bool glTexture;
	uint16 glTextureX;
	uint16 glTextureY;
	uint16 displayWidth;
	uint16 displayHeight;
	String bitmapName;
	bool sourceContainsAlpha;
	bool drawWithScaling;
	uint16 bpp;

	virtual uint16 getHeight() const {
		return height;
	}

	inline void setHeight(uint16 height) {
		this->height = height;
	}

	virtual inline uint16 getWidth() const {
		return width;
	}

	inline void setWidth(uint16 width) {
		this->width = width;
	}

	virtual inline float getRatio() const {
		return ratio;
	}

	inline void setRatio(float ratio) {
		this->ratio = ratio;
	}

	virtual inline void* getPixels() const {
		return pixels;
	}

	inline void setPixels(byte* pixels) {
		this->pixels = pixels;
	}

private:

	float ratio; // height / width
	uint16 width;
	uint16 height;
	void* pixels;

};

#endif /* ANDROIDBITMAP_H_ */
