/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

// Object map / Object click-area module header file

#ifndef SAGA_OBJECTMAP_H
#define SAGA_OBJECTMAP_H

#include "backends/platform/android/HitAreaHelper.h"

namespace Saga {


class HitZone {

public:
	typedef Common::Array<Point> ClickArea;
		typedef Common::Array<ClickArea> ClickAreas;

	void load(SagaEngine *vm, Common::MemoryReadStreamEndian *readStream, int index, int sceneNumber);

	int getIndex() const {
		return _index;
	}
	int getNameIndex() const {
		return _nameIndex;
	}
	int getSceneNumber() const {
		return _nameIndex;
	}
	int getActorsEntrance() const {
		return _scriptNumber;
	}
	int getScriptNumber() const {
		return _scriptNumber;
	}
	int getRightButtonVerb() const {
		return _rightButtonVerb;
	}
	int getFlags() const {
		return _flags;
	}
	void setFlag(HitZoneFlags flag) {
		_flags |= flag;
	}
	void clearFlag(HitZoneFlags flag) {
		_flags &= ~flag;
	}
	int getDirection() const {
		return ((_flags >> 4) & 0xF);
	}
	uint16 getHitZoneId() const {
		return objectIndexToId(kGameObjectHitZone, _index);
	}
	uint16 getStepZoneId() const {
		return objectIndexToId(kGameObjectStepZone, _index);
	}
	bool getSpecialPoint(Point &specialPoint) const;

	const ClickAreas& getClickAreas() const
	{
		return _clickAreas;
	}

#ifdef SAGA_DEBUG
	void draw(SagaEngine *vm, int color);	// for debugging
#endif
	bool hitTest(const Point &testPoint);

private:
	int _flags;				// Saga::HitZoneFlags
	int _rightButtonVerb;
	int _nameIndex;
	int _scriptNumber;
	int _index;

	ClickAreas _clickAreas;
};

typedef Common::Array<HitZone> HitZoneArray;

class ObjectMap {
public:
	ObjectMap(SagaEngine *vm) : _vm(vm), mCurrentHotspotsCount(0) {
		mCurrentHotspots = new Hotspot[HIT_AREA_MAX];
	}
	void load(const ByteArray &resourceData);
	void clear();
#ifdef SAGA_DEBUG
	void draw(const Point& testPoint, int color, int color2);	// for debugging
#endif
	int hitTest(const Point& testPoint, int forcedId = ID_NOTHING);
	HitZone *getHitZone(int16 index) {
		if (uint(index) >= _hitZoneList.size()) {
			return NULL;
		}
		return &_hitZoneList[index];
	}

	const HitZoneArray& getHitZoneArray() const {
		return _hitZoneList;
	}

	uint16 getInteractionHitAreas(Hotspot* rectArray);

	Hotspot hotspotHitTest(const Point &testPoint);

	void populateInteractionHitAreas();

	void cmdInfo();

private:

	bool canSelectClickArea(Common::Rect& rect, int hitZoneIndex);

	SagaEngine *_vm;

	HitZoneArray _hitZoneList;

	Hotspot* mCurrentHotspots;
	uint16 mCurrentHotspotsCount;
};

} // End of namespace Saga

#endif
