package org.iphsoft.simon1;

import java.io.DataInputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import org.iphsoft.simon1.AndroidPortAdditions.MusicOption;
import org.iphsoft.simon1.util.MyLog;

/**
 * This is a version of the GameFileHelper that install from a standalone APK
 * (without OBB expansion)
 * 
 * @author omergilad
 */
public class StandaloneGameFileHelper extends GameFileHelper {

	public StandaloneGameFileHelper(String destGameFolder, Language language)
	{
		super(destGameFolder, language);
		// TODO Auto-generated constructor stub
	}

	@Override
	protected void prepareGameFilesForLanguage(boolean onlyMusicFiles) throws IOException
	{

		MyLog.d("StandaloneGameFileHelper: prepareGameFilesForLanguage: " + mDestGameFolder + " "
				+ mLanguage.name() + " onlyMusicFiles " + onlyMusicFiles);

		MyLog.d("StandaloneGameFileHelper: prepareGameFilesForLanguage: preparing an empty directory");

		File destGameFolderFile;
		if (onlyMusicFiles)
		{
			destGameFolderFile = new File(mDestGameFolder);
		} else
		{
			// First, make sure we have a new empty directory.
			destGameFolderFile = initGameDirectory();
		}

		MyLog.d("StandaloneGameFileHelper: prepareGameFilesForLanguage: extracting game files");

		int progressMax = 0;
		int progress = 0;

		// Choose music entries
		String[] musicEntries = null;
		String musicSubFolder;
		if (AndroidPortAdditions.instance().getMusicOption() == MusicOption.ORIGINAL_RECORDING)
		{
			musicSubFolder = ORIGINAL_MUSIC_FOLDER;
		} else
		{
			musicSubFolder = ENHANCED_MUSIC_FOLDER;
		}

		musicSubFolder = musicSubFolder.substring(0, musicSubFolder.length() - 1);
		musicEntries = ScummVMApplication.getContext().getAssets()
				.list(BASE_ASSET_DIR + File.separator + musicSubFolder);
		progressMax += musicEntries.length;

		if (!onlyMusicFiles)
		{
			// Obtain all root entries
			String[] rootEntries = ScummVMApplication.getContext().getAssets().list(BASE_ASSET_DIR);
			MyLog.d("prepareGameFilesForLanguage: root entries: " + rootEntries.length);
			progressMax += rootEntries.length;

			// Obtain all language override entries
			String subFolder = mLanguage.getInnerFolderName();
			subFolder = subFolder.substring(0, subFolder.length() - 1);
			String[] languageEntries = ScummVMApplication.getContext().getAssets()
					.list(BASE_ASSET_DIR + File.separator + subFolder);
			MyLog.d("prepareGameFilesForLanguage: language entries: " + languageEntries.length);
			progressMax += languageEntries.length;

			// Copy all root entries
			mCopyBuffer = new byte[65536];
			for (String entry : rootEntries)
			{
				// Check if the entry is one of the language or music folders
				boolean ignore = false;
				String entryWithSeparator = entry + File.separator;
				for (Language lang : Language.values())
				{
					if (entryWithSeparator.equalsIgnoreCase(lang.getInnerFolderName()))
					{
						ignore = true;
					}
				}
				if (entryWithSeparator.equalsIgnoreCase(ORIGINAL_MUSIC_FOLDER)
						|| entryWithSeparator.equalsIgnoreCase(ENHANCED_MUSIC_FOLDER))
				{
					ignore = true;
				}

				if (ignore)
				{
					continue;
				}

				String assetName = BASE_ASSET_DIR + File.separator + entry;

				MyLog.d("prepareGameFilesForLanguage: prepareGameFilesForLanguage: root entry "
						+ assetName);

				if (isCancelled())
				{
					// Allow for interrupt
					return;
				}

				// Check if this is a sub folder
				if (ScummVMApplication.getContext().getAssets().list(assetName).length > 0)
				{
					copyAssetsRecursive(destGameFolderFile.getAbsolutePath(), assetName);
				} else
				{
					copyAssetToRoot(destGameFolderFile, assetName);
				}

				++progress;
				publishProgress(progress, progressMax);
			}

			// Copy all language entries
			for (String entry : languageEntries)
			{
				String assetName = BASE_ASSET_DIR + File.separator + mLanguage.getInnerFolderName()
						+ entry;

				MyLog.d("prepareGameFilesForLanguage: prepareGameFilesForLanguage: language entry "
						+ assetName);

				if (isCancelled())
				{
					// Allow for interrupt
					return;
				}

				copyAssetToRoot(destGameFolderFile, assetName);

				++progress;
				publishProgress(progress, progressMax);
			}
		}

		// Use music entries
		if (musicEntries != null)
		{

			for (String entry : musicEntries)
			{
				String assetName = BASE_ASSET_DIR + File.separator + musicSubFolder + File.separator
						+ entry;

				MyLog.d("prepareGameFilesForLanguage: prepareGameFilesForLanguage: original music entry "
						+ assetName);

				if (isCancelled())
				{
					// Allow for interrupt
					return;
				}

				copyAssetToRoot(destGameFolderFile, assetName);

				++progress;
				publishProgress(progress, progressMax);
			}
		}

		copyExtraFiles(destGameFolderFile);

		mCopyBuffer = null;

		// Sum the size of all copied files
		long totalGamefilesSize = folderSize(destGameFolderFile);

		MyLog.d("StandaloneGameFileHelper: prepareGameFilesForLanguage: totalGamefilesSize "
				+ totalGamefilesSize);

		AndroidPortAdditions.instance().setGameFilesSize(totalGamefilesSize);
		AndroidPortAdditions.instance().setShouldSwitchMusicFiles(false);
	}
}
