package org.iphsoft.simon1.ui;

import org.iphsoft.simon1.util.IHNMUtils;
import org.iphsoft.simon1.util.MediaPlayerHelper;
import org.iphsoft.simon1.util.MyLog;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.LinearGradient;
import android.graphics.Matrix;
import android.graphics.Shader;
import android.graphics.Typeface;
import android.util.AttributeSet;
import android.view.Gravity;
import android.view.View;

import com.mojotouch.fotaq.R;

public class IHNMButton extends MagicTextView {

	public IHNMButton(Context context)
	{
		super(context);
	}

	public IHNMButton(Context context, AttributeSet attrs, int defStyle)
	{
		super(context, attrs, defStyle);
	}

	public IHNMButton(Context context, AttributeSet attrs)
	{
		super(context, attrs);
	}

	@Override
	public void init(AttributeSet attrs)
	{
		super.init(attrs);

		if (!isInEditMode())
		{
			// Set font
			Typeface tf = Typeface.createFromAsset(getContext().getAssets(), "digitall.ttf");
			setTypeface(tf);
		}

		// Set text size
		float density = getResources().getDisplayMetrics().density;
		setTextSize(getResources().getDimensionPixelSize(R.dimen.button_text_size) / density);


		setLines(1);
		setMaxLines(1);

	//	setGravity(Gravity.TOP | Gravity.CENTER_HORIZONTAL);

		setText(getText().toString().toUpperCase());

		updateState();
	}

	@Override
	public void setText(CharSequence text, BufferType type)
	{
		super.setText(text.toString().toUpperCase(), type);
	}

	@Override
	protected void drawableStateChanged()
	{
		super.drawableStateChanged();

		updateState();
		invalidate();
	}

	@Override
	protected void onLayout(boolean changed, int left, int top, int right, int bottom)
	{
		super.onLayout(changed, left, top, right, bottom);

		if (changed)
		{
			updateState();
		}
	}
	
	@Override
	public void setOnClickListener(OnClickListener l)
	{
		super.setOnClickListener(mSoundPlayingListener);
		mInnerOnClickListener = l;
	}
	
	OnClickListener mSoundPlayingListener = new OnClickListener()
	{
		
		@Override
		public void onClick(View v)
		{
			MediaPlayerHelper.playAudioResource(getContext(), R.raw.click);
			
			if (mInnerOnClickListener != null)
				mInnerOnClickListener.onClick(v);
			
		}
	};
	
	OnClickListener mInnerOnClickListener = null;

	private void updateState()
	{
		// Get the relevant drawable state
		boolean statePressed = false, stateEnabled = false;
		int[] states = getDrawableState();
		for (int state : states)
		{
			if (state == android.R.attr.state_enabled)
				stateEnabled = true;
			else if (state == android.R.attr.state_pressed)
				statePressed = true;
		}

		if (getHeight() >= 0)
		{
			float shadowRadius = 0.0f;
			int[] colors;
			if (stateEnabled == false)
			{
				colors = Gradients.IHNM_GRADIENT_COLORS_DISABLED;
			} else if (statePressed)
			{
				shadowRadius = 2.0f;
				colors = Gradients.IHNM_GRADIENT_COLORS_PRESSED;
			} else
			{
				shadowRadius = 1.5f;
				colors = Gradients.IHNM_GRADIENT_COLORS;
			}
			
			clearOuterShadows();
			
			// Adjust shadow radious to screen density
			float scale = getResources().getDisplayMetrics().density;
			shadowRadius *= scale;
			
			addOuterShadow(shadowRadius, 0.0f, 0.0f, 0xff918c4c);


			Shader shader = new LinearGradient(0, 0, 0, getHeight(), colors, null,
					Shader.TileMode.CLAMP);
			// Matrix matrix = new Matrix();
			// matrix.setRotate(90);
			// shader.setLocalMatrix(matrix);
			getPaint().setShader(shader);
		}

	}
}
